{% extends "base.html" %}
{% load i18n %}

{% block meta_title %}{% trans "Home" %}{% endblock %}
{% block title %}{% trans "Home" %}{% endblock %}

{% block breadcrumb_menu %}
<li class="active">{% trans "Home" %}</li>
{% endblock %}

{% block main %}
{% trans "This is the homepage." %}
{% endblock %}
