<div style="color:blue;height:25px;width:100%;background:#8f8;">
This is your site's Top Banner. It's a good place for your site's masthead, or perhaps an ad.<br>
Place a file named "TopBanner.html" in your templates folder, make it empty if you want none.
</div>
